@@ -49,9 +49,6 @@ enum PatchType {POINT_PATCH_TYPE,
 
 /** @name Macros for DOMAIN */
 /*@{*/
-#define DOMAIN_MIDPOINT(p)                              ((p)->MidPoint)
-#define DOMAIN_RADIUS(p)                                ((p)->radius)
-#define DOMAIN_CONVEX(p)                                ((p)->domConvex)
 #define DOMAIN_NSEGMENT(p)                              ((p)->numOfSegments)
 #define DOMAIN_NCORNER(p)                               ((p)->numOfCorners)
 #define DOMAIN_NPARTS(p)                                ((p)->nParts)
@@ -60,61 +57,20 @@ enum PatchType {POINT_PATCH_TYPE,
 
 /** @name Macros for STD_BVP */
 /*@{*/
-#define STD_BVP_NAME(p)                                 ENVITEM_NAME(p)
-
 #define STD_BVP_DOMAIN(p)                               ((p)->Domain)
-#define STD_BVP_PROBLEM(p)                              ((p)->Problem)
 
-#define STD_BVP_MIDPOINT(p)                             ((p)->MidPoint)
-#define STD_BVP_RADIUS(p)                               ((p)->radius)
-#define STD_BVP_CONVEX(p)                               ((p)->domConvex)
-
-#define STD_BVP_NCORNER(p)                              ((p)->ncorners)
 #define STD_BVP_NSIDES(p)                               ((p)->nsides)
 #define STD_BVP_SIDEOFFSET(p)                   ((p)->sideoffset)
-#define STD_BVP_PATCHES(p)                              ((p)->patches)
 #define STD_BVP_PATCH(p,i)                              ((p)->patches[i])
-#define STD_BVP_CORNERPATCH(p,i)                ((p)->patches[i])
-#define STD_BVP_LINEPATCH(p,i)                  ((p)->patches[i+STD_BVP_NCORNER(p)])
-#define STD_BVP_SIDEPATCH(p,i)                  ((p)->patches[i+STD_BVP_SIDEOFFSET(p)])
 
 #define STD_BVP_NSUBDOM(p)                              ((p)->numOfSubdomains)
 #define STD_BVP_NDOMPART(p)                             ((p)->nDomainParts)
 #define STD_BVP_S2P_PTR(p)                              ((p)->s2p)
 #define STD_BVP_S2P(p,s)                                ((p)->s2p[s])
-#define STD_BVP_NPATCH(p)                               ((p)->nPatch)
-#define STD_BVP_NCOEFFPROC(p)                   ((p)->numOfCoeffFct)
-#define STD_BVP_NUSERPROC(p)                    ((p)->numOfUserFct)
-#define STD_BVP_CONFIGPROC(p)                   ((p)->ConfigProc)
-#define STD_BVP_COEFFPROC(p,i)                  ((CoeffProcPtr)((p)->CU_ProcPtr[i]))
-#define STD_BVP_USERPROC(p,i)                   ((UserProcPtr)((p)->CU_ProcPtr[i+STD_BVP_NCOEFFPROC(p)]))
 
 #define GetSTD_BVP(p)                           ((STD_BVP *)(p))
 /*@}*/
 
-/****************************************************************************/
-/*                                                                          */
-/* macros for boundary segments                                             */
-/*                                                                          */
-/****************************************************************************/
-
-/** @name Macros for boundary segments */
-/*@{*/
-#define SEG_LEFT(p)                                             ((p)->left)
-#define SEG_RIGHT(p)                                    ((p)->right)
-#define SEG_ID(p)                                               ((p)->id)
-#define SEG_TYPE(p)                                             ((p)->segType)
-#define SEG_POINTS(p)                                   ((p)->points)
-#define SEG_POINT(p,i)                                  ((p)->points[i])
-#define SEG_RESOLUTION(p)                               ((p)->resolution)
-#define SEG_ALPHA(p)                                    ((p)->alpha)
-#define SEG_FROM(p,i)                                   ((p)->alpha[i])
-#define SEG_BETA(p)                                             ((p)->beta)
-#define SEG_TO(p,i)                                             ((p)->beta[i])
-#define SEG_FUNC(p)                                             ((p)->BndSegFunc)
-#define SEG_DATA(p)                                             ((p)->data)
-/*@}*/
-
 /****************************************************************************/
 /*                                                                          */
 /* macros for patches                                                       */
@@ -144,7 +100,6 @@ enum {PATCH_FIXED,
 #define PARAM_PATCH_LEFT(p)     (p)->pa.left
 #define PARAM_PATCH_RIGHT(p)    (p)->pa.right
 #define PARAM_PATCH_POINTS(p,i) (p)->pa.points[i]
-#define PARAM_PATCH_RES(p)              ((p)->pa.resolution)
 #define PARAM_PATCH_RANGE(p)    (p)->pa.range
 #define PARAM_PATCH_BS(p)       (p)->pa.BndSegFunc
 #define PARAM_PATCH_BSD(p)      (p)->pa.bs_data
@@ -188,21 +143,12 @@ struct domain {
   /** \brief Fields for environment directory */
   NS_PREFIX ENVDIR d;
 
-  /** \brief A point in the middle of the domain */
-  DOUBLE MidPoint[DIM];
-
-  /** \brief Defines sphere around MidPoint containing the domain */
-  DOUBLE radius;
-
   /** \brief Number of boundary segments */
   INT numOfSegments;
 
   /** \brief Number of corner points */
   INT numOfCorners;
 
-  /** \brief Is the domain convex? */
-  INT domConvex;
-
   /** @name Description of domain parts */
   /*@{*/
 
@@ -236,9 +182,6 @@ struct boundary_segment {
   /** \brief Numbers of the vertices (ID) */
   INT points[CORNERS_OF_BND_SEG];
 
-  /** \brief Measure for the curvature */
-  INT resolution;
-
   /** \brief Parameter interval used*/
   DOUBLE alpha[DIM_OF_BND],beta[DIM_OF_BND];
 
@@ -386,15 +329,6 @@ struct std_BoundaryValueProblem
 
   /** @name Domain part */
   /*@{*/
-  /** \brief Center of a sphere containing the domain */
-  DOUBLE MidPoint[DIM];
-
-  /** \brief Radius of a sphere containing the domain */
-  DOUBLE radius;
-
-  /** \brief 1 if domain is convex, 0 if not     */
-  INT domConvex;
-
   /** \brief Number of subdomains, exterior not counted                */
   INT numOfSubdomains;
 
@@ -570,9 +504,6 @@ struct parameter_patch {
   /** \brief Id of left and right subdomain */
   INT left,right;
 
-  /** \brief Measure for curvature */
-  INT resolution;
-
   /** \brief Ids of points */
   INT points[CORNERS_OF_BND_SEG];
 
@@ -660,12 +591,6 @@ typedef struct bnd_ps BND_PS;
 
 DOMAIN *GetDomain                           (const char *name);
 
-/* BVP definition */
-INT   STD_BVP_Configure           (INT argc, char **argv);
-
-/* scanning of coordinates */
-INT   ReadAndPrintArgvPosition    (const char *name, INT argc, char **argv, DOUBLE *pos);
-
 END_UGDIM_NAMESPACE
 
 #endif
