@@ -24,7 +24,7 @@
 #include <cassert>
 
 #include "general.h"
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 
 #include "gm.h"
 #include "ugm.h"
@@ -68,7 +68,6 @@ INT NS_DIM_PREFIX nb_offset[TAGS];
 INT NS_DIM_PREFIX evector_offset[TAGS];
 INT NS_DIM_PREFIX svector_offset[TAGS];
 INT NS_DIM_PREFIX side_offset[TAGS];
-INT NS_DIM_PREFIX data_offset[TAGS];
 
 GENERAL_ELEMENT * NS_DIM_PREFIX element_descriptors[TAGS];
 GENERAL_ELEMENT * NS_DIM_PREFIX reference_descriptors[MAX_CORNERS_OF_ELEM+1];
@@ -854,11 +853,6 @@ static INT ProcessElementDescription (MULTIGRID *theMG, GENERAL_ELEMENT *el)
   }
         #endif
 
-  if (EDATA_DEF_IN_MG(theMG)) {
-    data_offset[tag] = p_count;
-    p_count++;
-  }
-
   /* so far for an inner element */
   el->inner_size = sizeof(struct generic_element) + (p_count-1)*sizeof(void *);
 
@@ -946,14 +940,14 @@ INT NS_DIM_PREFIX PreInitElementTypes (void)
 
 INT NS_DIM_PREFIX InitElementTypes (MULTIGRID *theMG)
 {
-  INT i,err;
+  INT err;
 
   if (theMG==NULL)
     return(GM_ERROR);
 
 #ifndef ModelP
   /* release allocated OBJTs */
-  for (i=0; i<nOBJT; i++)
+  for (INT i=0; i<nOBJT; i++)
     if (ReleaseOBJT (OBJT4Elements[i]))
       return (GM_ERROR);
   nOBJT=0;
