@@ -47,7 +47,7 @@
 #include "general.h"
 #include "fifo.h"
 
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 #include "ugstruct.h"
 
 #include "evm.h"
@@ -107,7 +107,6 @@ using namespace PPIF;
 /*																			*/
 /****************************************************************************/
 
-static char buffer[4*256];                      /* general purpose text buffer			*/
 static DOUBLE hghost_overlap = 1.0;
 
 REP_ERR_FILE;
@@ -1098,61 +1097,8 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
                    me,EID_PRTX(theElement));
         nerrors++;
       }
-      else
-      {
-        CORNER_COORDINATES(theElement,n,x);
-        V_DIM_CLEAR(center);
-        for (i=0; i<n; i++)
-          V_DIM_ADD(center,x[i],center)
-        V_DIM_SCALE(1.0/(DOUBLE)n,center)
-
-        /* search in element list of grid level below */
-        {
-          GRID		*downGrid;
-          MULTIGRID	*theMG;
-          INT			downlevel;
-
-          theMG		= MYMG(theGrid);
-          downlevel	= GLEVEL(theGrid)-1;
-          downGrid	= GRID_ON_LEVEL(theMG,downlevel);
-
-          theFather = FindElementFromPosition(downGrid,center);
-          if (theFather != NULL)
-            UserWriteF(PFMT "ELEM(" EID_FMTX ") has no fatherpointer but father="
-                       EID_FMTX "\n",me,EID_PRTX(theElement),EID_PRTX(theFather));
-
-          if (0)
-            for (theFather = PFIRSTELEMENT(downGrid);
-                 theFather != NULL; theFather = SUCCE(theFather))
-            {
-              k = PointInElement(center,theFather);
-              switch (k)
-              {
-                case 0:
-                UserWriteF(PFMT "ELEM(" EID_FMTX ") PointInElement() returned"
-                           " error",me,EID_PRTX(theElement));
-                break;
-                case 1:
-                case 2:
-                case 3:
-                case 4:
-                /* point (nearly) in father */
-                UserWriteF(PFMT "ELEM(" EID_FMTX ") has no fatherpointer but father="
-                           EID_FMTX "\n",me,EID_PRTX(theElement),EID_PRTX(theFather));
-                break;
-                case 5:
-                /* point not in father */
-                break;
-                default:
-                UserWriteF(PFMT "ELEM(" EID_FMTX ") PointInElement() unexpected"
-                           " Returncode=%d",me,EID_PRTX(theElement),k);
-                break;
-              }
-            }
-        }
     }
   }
-}
 #endif
 
   /* check son information */
@@ -1234,7 +1180,7 @@ INT CheckSubdomains (MULTIGRID *theMG)
 
 static INT CheckElementSubdomains (GRID *theGrid, ELEMENT *theElement, INT *NodeError, INT *EdgeError, INT *NbError, INT *FatherError, INT *errors)
 {
-  INT side,found,i,j,k,bserror,nerrors,sdid,sc;
+  INT side,found,i,j,k,nerrors,sdid,sc;
   NODE    *theNode,*n1,*n2,*nbn1,*nbn2,*nbn3,*nbn4;
   EDGE    *theEdge,*father_edge;
   ELEMENT *theFather;
@@ -1246,8 +1192,6 @@ static INT CheckElementSubdomains (GRID *theGrid, ELEMENT *theElement, INT *Node
   *FatherError = 0;
   nerrors    = 0;
 
-  bserror = 0;
-
   /* check side information */
   for (i=0; i<SIDES_OF_ELEM(theElement); i++)
   {
