@@ -20,10 +20,6 @@
 /*																			*/
 /****************************************************************************/
 
-#ifdef __MPW32__
-#pragma segment cmd
-#endif
-
 /****************************************************************************/
 /*																			*/
 /* include files															*/
