@@ -38,7 +38,7 @@
 #include "gm.h"       /* for data structure               */
 #include "evm.h"      /* for data structure               */
 #include "general.h"
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 
 #include "ugblas.h"
 #include "disctools.h"
@@ -2163,7 +2163,7 @@ static void PrintSingleVectorX (const VECTOR *v, const VECDATA_DESC *X, INT vcla
 
         #ifdef Debug
   if (Printf!=PrintDebug)
-    PRINTDEBUG(np,1,("%d: %s",me,buffer));
+    PRINTDEBUG(np,1,("%d: %s",PPIF::me,buffer));
         #endif
 
   return;
@@ -2378,7 +2378,7 @@ INT NS_DIM_PREFIX PrintDiagMatrix (GRID *g, MATDATA_DESC *Mat, INT vclass, INT v
     i += sprintf(buffer+i,"\n");
     UserWrite(buffer);
 
-    PRINTDEBUG(np,1,("%d: %s",me,buffer));
+    PRINTDEBUG(np,1,("%d: %s",PPIF::me,buffer));
   }
 
 
@@ -2388,50 +2388,3 @@ INT NS_DIM_PREFIX PrintDiagMatrix (GRID *g, MATDATA_DESC *Mat, INT vclass, INT v
 
   return(NUM_OK);
 }
-
-#ifdef __INTERPOLATION_MATRIX__
-/****************************************************************************/
-/** \brief Print the interpolation matrix list
-
-   \param g - pointer to a grid
-   \param V - pointer to vector descriptor
-   \param vclass - class number
-   \param vnclass - class number
-
-   This function prints the values of the interpolation matrix list
-   for all vectors with class smaller
-   or equal to vclass and next class smaller or equal to vnclass.
-
-   RETURN VALUE:
-   .n    NUM_OK if ok
-   .n    NUM_ERROR if error occured
- */
-/****************************************************************************/
-
-INT NS_DIM_PREFIX PrintIMatrix (GRID *g, VECDATA_DESC *V, INT vclass, INT vnclass)
-{
-  VECTOR *v;
-  MATRIX *m;
-  INT Mcomp,rcomp,ccomp,i,j;
-
-  for (v=FIRSTVECTOR(g); v!= NULL; v=SUCCVC(v))
-  {
-    if (VCLASS(v) > vclass) continue;
-    if (VNCLASS(v) > vnclass) continue;
-    rcomp = VD_NCMPS_IN_TYPE(V,VTYPE(v));
-    for (i=0; i<rcomp; i++)
-    {
-      for (m=VISTART(v); m!=NULL; m = MNEXT(m))
-      {
-        ccomp = VD_NCMPS_IN_TYPE(V,MDESTTYPE(m));
-        Mcomp = i * ccomp;
-        for (j=0; j<ccomp; j++)
-          UserWriteF("%+5.3f ",MVALUE(m,Mcomp+j));
-      }
-      UserWrite("\n");
-    }
-  }
-
-  return(NUM_OK);
-}
-#endif  /* __INTERPOLATION_MATRIX__ */
