@@ -33,7 +33,7 @@
 #include <cstring>
 #include <ctype.h>
 
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 #include "enrol.h"
 #include "ugtypes.h"
 #include "misc.h"
@@ -780,81 +780,6 @@ INT NS_DIM_PREFIX VDmatchesVT (const VECDATA_DESC *vd, const VEC_TEMPLATE *vt)
   return (YES);
 }
 
-/****************************************************************************/
-/** \brief Create a VECDATA_DESC as a sub descriptor from a vector template
-
-   \param vd			- make a sub desc of this VECDATA_DESC
-   \param vt			- template containing sub descriptor
-   \param sub			- index of sub descriptor in template
-   \param subvd		- handle to created sub descriptor
-
-   This function creates a sub descriptor to a given VECDATA_DESC according to the given
-   sub descriptor of a template.
-
-   \return <ul>
-   <li>         0: ok
-   <li>     n: if an error occured
- */
-/****************************************************************************/
-
-INT NS_DIM_PREFIX VDsubDescFromVT (const VECDATA_DESC *vd, const VEC_TEMPLATE *vt, INT sub, VECDATA_DESC **subvd)
-{
-  FORMAT *fmt;
-  SUBVEC *subv;
-  SHORT SubComp[MAX_VEC_COMP];
-  const SHORT *offset,*Comp;
-  INT i,k,l,type,nc,nn,cmp;
-  char SubName[MAX_VEC_COMP],buffer[NAMESIZE];
-
-  if (!VDmatchesVT(vd,vt))
-    REP_ERR_RETURN(1);
-
-  ASSERT(sub<VT_NSUB(vt));
-
-  subv = VT_SUB(vt,sub);
-
-  /* generate name and see if desc already exists */
-  strcpy(buffer,SUBV_NAME(subv));
-  strcat(buffer,GENERATED_NAMES_SEPERATOR);
-  strcat(buffer,ENVITEM_NAME(vd));
-  *subvd = GetVecDataDescByName(MD_MG(vd),buffer);
-  if (*subvd != NULL) {
-    if (TransmitLockStatusVD(vd,*subvd))
-      REP_ERR_RETURN(1);
-    return(0);
-  }
-
-  fmt = MGFORMAT(VD_MG(vd));
-
-  offset = VD_OFFSETPTR(vd);
-  Comp = VM_COMPPTR(vd);
-
-  /* compute sub components */
-  k = 0;
-  for (type=0; type<NVECTYPES; type++)
-  {
-    nc = SUBV_NCOMP(subv,type);
-    nn = VD_NCMPS_IN_TYPE(vd,type);
-    for (i=0; i<nc; i++)
-    {
-      l = SUBV_COMP(subv,type,i);
-      if (l>=nn)
-        REP_ERR_RETURN (1);
-      cmp = offset[type]+l;
-      SubComp[k] = Comp[cmp];
-      SubName[k] = VT_COMPNAME(vt,cmp);
-      k++;
-    }
-  }
-  *subvd = CreateSubVecDesc(VD_MG(vd),buffer,SUBV_NCOMPS(subv),SubComp,SubName);
-  if (*subvd == NULL)
-    REP_ERR_RETURN (1);
-  if (TransmitLockStatusVD(vd,*subvd))
-    REP_ERR_RETURN(1);
-
-  return (0);
-}
-
 /****************************************************************************/
 /** \brief
         VDsubDescFromVS - create a VECDATA_DESC as a vector sub descriptor
@@ -881,7 +806,6 @@ INT NS_DIM_PREFIX VDsubDescFromVT (const VECDATA_DESC *vd, const VEC_TEMPLATE *v
 
 INT NS_DIM_PREFIX VDsubDescFromVS (const VECDATA_DESC *vd, const SUBVEC *subv, VECDATA_DESC **subvd)
 {
-  FORMAT *fmt;
   SHORT SubComp[MAX_VEC_COMP];
   const SHORT *offset,*Comp;
   INT i,k,l,type,nc,nn,cmp;
@@ -898,8 +822,6 @@ INT NS_DIM_PREFIX VDsubDescFromVS (const VECDATA_DESC *vd, const SUBVEC *subv, V
     return(0);
   }
 
-  fmt = MGFORMAT(VD_MG(vd));
-
   offset = VD_OFFSETPTR(vd);
   Comp = VM_COMPPTR(vd);
 
@@ -1084,7 +1006,6 @@ static INT MTmatchesVTxVT (const MAT_TEMPLATE *mt, const VEC_TEMPLATE *rvt, cons
 
 INT NS_DIM_PREFIX MDsubDescFromMT (const MATDATA_DESC *md, const MAT_TEMPLATE *mt, INT sub, MATDATA_DESC **submd)
 {
-  FORMAT *fmt;
   SUBMAT *subm;
   SHORT *CmpsInType[NMATTYPES],SubComp[MAX_MAT_COMP];
   INT i,k,l,type,nc,nn,cmp;
@@ -1107,7 +1028,6 @@ INT NS_DIM_PREFIX MDsubDescFromMT (const MATDATA_DESC *md, const MAT_TEMPLATE *m
       REP_ERR_RETURN(1);
     return(0);
   }
-  fmt = MGFORMAT(MD_MG(md));
 
   /* compute sub components */
   k = 0;
@@ -1138,246 +1058,6 @@ INT NS_DIM_PREFIX MDsubDescFromMT (const MATDATA_DESC *md, const MAT_TEMPLATE *m
   return (0);
 }
 
-/****************************************************************************/
-/** \brief Create a MATDATA_DESC as a sub descriptor from a vector template
-
-   \param md			- make a sub desc of this MATDATA_DESC
-   \param vt			- template containing sub descriptor
-   \param sub			- index of sub descriptor in template
-   \param submd		- handle to created sub descriptor
-
-   This function creates a sub descriptor to a given MATDATA_DESC according to the given
-   subv of a vector template. The matrix is composed as tensor product of the subv.
-
-   \return <ul>
-   <li>         0: ok </li>
-   <li>  n: if an error occured </li>
-   </ul>
- */
-/****************************************************************************/
-
-INT NS_DIM_PREFIX MDsubDescFromVT (const MATDATA_DESC *md, const VEC_TEMPLATE *vt, INT sub, MATDATA_DESC **submd)
-{
-  FORMAT *fmt;
-  SUBVEC *subv;
-  SHORT SubComp[MAX_MAT_COMP];
-  SHORT RComp[NMATTYPES];
-  SHORT CComp[NMATTYPES];
-  INT i,j,k,l,rt,ct,mt,nr,nc,NC,nn,cmp;
-  char SubName[MAX_MAT_COMP],buffer[NAMESIZE];
-
-  PrintErrorMessageF('E',"MDsubDescFromVT","not yet implemented");
-  REP_ERR_RETURN (1);
-
-  fmt    = MGFORMAT(MD_MG(md));
-
-  ASSERT(sub<VT_NSUB(vt));
-
-  subv   = VT_SUB(vt,sub);
-
-  /* generate name and see if desc already exists */
-  strcpy(buffer,SUBV_NAME(subv));
-  strcat(buffer,SUBV_NAME(subv));
-  strcat(buffer,GENERATED_NAMES_SEPERATOR);
-  strcat(buffer,ENVITEM_NAME(md));
-  *submd = GetMatDataDescByName(MD_MG(md),buffer);
-  if (*submd != NULL) {
-    if (TransmitLockStatusMD(md,*submd))
-      REP_ERR_RETURN(1);
-    return(0);
-  }
-
-  /* compute sub components */
-  k  = 0;
-  for (rt=0; rt<NVECTYPES; rt++)
-    for (ct=0; ct<NVECTYPES; ct++)
-    {
-      nr = SUBV_NCOMP(subv,rt);
-      nc = SUBV_NCOMP(subv,ct);
-      mt = MTP(rt,ct);
-      if (nr*nc==0)
-      {
-        RComp[mt] = CComp[mt] = 0;
-        continue;
-      }
-      RComp[mt] = nr;
-      CComp[mt] = nc;
-      NC = MD_COLS_IN_RT_CT(md,rt,ct);
-      nn = MD_ROWS_IN_RT_CT(md,rt,ct) * NC;
-      for (i=0; i<nr; i++)
-        for (j=0; j<nc; j++)
-        {
-          l = SUBV_COMP(subv,rt,i) * NC + SUBV_COMP(subv,ct,j);
-          if (l>=nn)
-            REP_ERR_RETURN (1);
-          /* cmp = #@@@ */
-          PrintErrorMessageF('E',"MDsubDescFromVT","not yet implemented");
-          REP_ERR_RETURN (1);
-          SubComp[k] = MD_MCMP_OF_MTYPE(md,mt,cmp);
-          SubName[2*k]   = VM_COMP_NAME(md,2*cmp);
-          SubName[2*k+1] = VM_COMP_NAME(md,2*cmp+1);
-          k++;
-        }
-    }
-
-  /* #@@@@
-   *submd = CreateSubMatDesc(MD_MG(md),buffer,SubName,RComp,CComp,SubComp); */
-  if (*submd == NULL)
-    REP_ERR_RETURN (1);
-  if (TransmitLockStatusMD(md,*submd))
-    REP_ERR_RETURN(1);
-
-  return (0);
-}
-
-/****************************************************************************/
-/** \brief Create a MATDATA_DESC as a sub descriptor from a vector template
-
-   \param md			- make a sub desc of this MATDATA_DESC
-   \param rvt			- template containing row sub descriptor
-   \param rsub		- index of row sub descriptor in template
-   \param cvt			- template containing col sub descriptor
-   \param csub		- index of col sub descriptor in template
-   \param submd		- handle to created sub descriptor
-
-   This function creates a sub descriptor to a given MATDATA_DESC according to the given
-   subv of a vector template. The matrix is composed as tensor product of the subv descriptors.
-
-   \return <ul>
-   <li>         0: ok </li>
-   <li>  n: if an error occured </li>
-   </ul>
- */
-/****************************************************************************/
-
-INT NS_DIM_PREFIX MDsubDescFromVTxVT (const MATDATA_DESC *md, const VEC_TEMPLATE *rvt, INT rsub,
-                                      const VEC_TEMPLATE *cvt, INT csub,
-                                      MATDATA_DESC **submd)
-{
-  FORMAT *fmt;
-  const VEC_TEMPLATE *vt;
-  SUBVEC *rsubv,*csubv,*subv;
-  SHORT SubComp[MAX_MAT_COMP];
-  const SHORT *offset,*Comp;
-  SHORT RComp[NMATTYPES];
-  SHORT CComp[NMATTYPES];
-  INT i,j,k,l,rt,ct,mt,nr,nc,NC,nn,cmp,type,n;
-  char SubName[MAX_MAT_COMP],buffer[NAMESIZE];
-
-  PrintErrorMessageF('E',"MDsubDescFromVTxVT","not yet implemented");
-  return (1);
-
-  fmt    = MGFORMAT(MD_MG(md));
-
-  if (!MDmatchesVTxVT(md,rvt,cvt))
-    REP_ERR_RETURN(1);
-
-  if ((rsub==FULL_TPLT) && (csub==FULL_TPLT))
-    REP_ERR_RETURN(1);
-
-  if ((rsub==FULL_TPLT) || (csub==FULL_TPLT))
-  {
-    /* create subv identical to template */
-    subv = (SUBVEC*)AllocEnvMemory(sizeof(SUBVEC));
-    if (subv==NULL)
-      REP_ERR_RETURN(1);
-
-    memset(subv,0,sizeof(SUBVEC));
-
-    if (rsub==FULL_TPLT)
-    {
-      vt = rvt;
-      rsubv = subv;
-      ASSERT(csub<VT_NSUB(cvt));
-      csubv   = VT_SUB(cvt,csub);
-    }
-    else
-    {
-      vt = cvt;
-      csubv = subv;
-      ASSERT(rsub<VT_NSUB(rvt));
-      rsubv   = VT_SUB(rvt,rsub);
-    }
-    for (type=0; type<NVECTYPES; type++)
-    {
-      n = SUBV_NCOMP(subv,type) = VT_COMP(vt,type);
-      for (i=0; i<n; i++)
-        SUBV_COMP(subv,type,i) = i;
-    }
-  }
-  else
-  {
-    ASSERT(rsub<VT_NSUB(rvt));
-    rsubv   = VT_SUB(rvt,rsub);
-    ASSERT(csub<VT_NSUB(cvt));
-    csubv   = VT_SUB(cvt,csub);
-  }
-
-  /* generate name and see if desc already exists */
-  if (rsub==FULL_TPLT)
-    strcpy(buffer,ENVITEM_NAME(rvt));
-  else
-    strcpy(buffer,SUBV_NAME(rsubv));
-  if (csub==FULL_TPLT)
-    strcpy(buffer,ENVITEM_NAME(cvt));
-  else
-    strcat(buffer,SUBV_NAME(csubv));
-  strcat(buffer,GENERATED_NAMES_SEPERATOR);
-  strcat(buffer,ENVITEM_NAME(md));
-  *submd = GetMatDataDescByName(MD_MG(md),buffer);
-  if (*submd != NULL) {
-    if (TransmitLockStatusMD(md,*submd))
-      REP_ERR_RETURN(1);
-    return(0);
-  }
-
-  offset = MD_OFFSETPTR(md);
-  Comp   = VM_COMPPTR(md);
-
-  /* compute sub components */
-  k  = 0;
-  for (rt=0; rt<NVECTYPES; rt++)
-    for (ct=0; ct<NVECTYPES; ct++)
-    {
-      nr = SUBV_NCOMP(rsubv,rt);
-      nc = SUBV_NCOMP(csubv,ct);
-      mt = MTP(rt,ct);
-      if (nr*nc==0)
-      {
-        RComp[mt] = CComp[mt] = 0;
-        continue;
-      }
-      RComp[mt] = nr;
-      CComp[mt] = nc;
-      NC = MD_COLS_IN_RT_CT(md,rt,ct);
-      nn = MD_ROWS_IN_RT_CT(md,rt,ct) * NC;
-      for (i=0; i<nr; i++)
-        for (j=0; j<nc; j++)
-        {
-          l = SUBV_COMP(rsubv,rt,i) * NC + SUBV_COMP(csubv,ct,j);
-          if (l>=nn)
-            REP_ERR_RETURN (1);
-          cmp = offset[mt]+l;
-          SubComp[k] = Comp[cmp];
-          SubName[2*k]   = VM_COMP_NAME(md,2*cmp);
-          SubName[2*k+1] = VM_COMP_NAME(md,2*cmp+1);
-          k++;
-        }
-    }
-
-  if ((rsub==FULL_TPLT) || (csub==FULL_TPLT))
-    FreeEnvMemory(subv);
-  /* #@@@
-   *submd = CreateSubMatDesc(MD_MG(md),buffer,SubName,RComp,CComp,SubComp);*/
-  if (*submd == NULL)
-    REP_ERR_RETURN (1);
-  if (TransmitLockStatusMD(md,*submd))
-    REP_ERR_RETURN(1);
-
-  return (0);
-}
-
-
 static INT RemoveTemplateSubs (FORMAT *fmt)
 {
   ENVITEM *item;
@@ -2809,7 +2489,7 @@ INT NS_DIM_PREFIX CreateFormatCmd (INT argc, char **argv)
   VectorDescriptor vd[MAXVECTORS];
   MatrixDescriptor md[MAXMATRICES*MAXVECTORS];
   INT opt,i,j,size,type,type2,rtype,ctype,nvec,nmat,nvd,nmd;
-  INT edata,ndata,nodeelementlist;
+  INT ndata,nodeelementlist;
   INT po2t[MAXDOMPARTS][MAXVOBJECTS],MaxTypes,TypeUsed[MAXVECTORS];
   SHORT ConnDepth[NMATTYPES],ImatTypes[NVECTYPES];
   SHORT VecStorageNeeded[NVECTYPES],MatStorageNeeded[NMATTYPES];
@@ -2817,7 +2497,7 @@ INT NS_DIM_PREFIX CreateFormatCmd (INT argc, char **argv)
   int n,depth;
 
   /* scan name of format */
-  if ((sscanf(argv[0],expandfmt(CONCAT3(" newformat %",NAMELENSTR,"[ -~]")),formatname)!=1) || (strlen(formatname)==0)) {
+  if (sscanf(argv[0],expandfmt(" newformat %" NAMELENSTR "[ -~]"), formatname) != 1 || strlen(formatname) == 0) {
     PrintErrorMessage('E',"newformat","no format name specified");
     REP_ERR_RETURN (1);
   }
@@ -2845,7 +2525,7 @@ INT NS_DIM_PREFIX CreateFormatCmd (INT argc, char **argv)
     MatStorageNeeded[type] = ConnDepth[type] = 0;
   for (type=0; type<NMATTYPES; type++) ConnDepth[type] = 0;
   nvec = nmat = 0;
-  edata = ndata = nodeelementlist = 0;
+  ndata = nodeelementlist = 0;
 
   /* scan type option or set default po2t */
   if (ScanTypeOptions(argc,argv,po2t,&MaxTypes,TypeNames)) {
@@ -2889,11 +2569,6 @@ INT NS_DIM_PREFIX CreateFormatCmd (INT argc, char **argv)
       }
       break;
 
-    case 'e' :
-      if (sscanf(argv[opt],"e %d",&n) == 1)
-        edata = n;
-      break;
-
     case 'n' :
       if (sscanf(argv[opt],"n %d",&n) == 1)
         ndata = n;
@@ -3002,7 +2677,7 @@ INT NS_DIM_PREFIX CreateFormatCmd (INT argc, char **argv)
   newFormat = CreateFormat(formatname,0,0,
                            (ConversionProcPtr)NULL,(ConversionProcPtr)NULL,(ConversionProcPtr)NULL,
                            PrintTypeVectorData,PrintTypeMatrixData,
-                           nvd,vd,nmd,md,ImatTypes,po2t,nodeelementlist,edata,ndata);
+                           nvd,vd,nmd,md,ImatTypes,po2t,nodeelementlist,ndata);
   if (newFormat==NULL)
   {
     PrintErrorMessage('E',"newformat","failed creating the format");
