@@ -316,7 +316,7 @@ static void ConstructDesc (TYPE_DESC *desc)
 
   desc->nPointers = 0;
   desc->nElements = 0;
-  desc->cmask     = NULL;
+  desc->cmask     = nullptr;
   desc->hasHeader = false;
   desc->offsetHeader = 0;
 
@@ -426,8 +426,8 @@ static void AttachMask (TYPE_DESC *desc)
   unsigned char mask;
 
   /* get storage for mask */
-  desc->cmask = (unsigned char *)AllocFix(desc->size);
-  if (desc->cmask==0)
+  desc->cmask = std::make_unique<unsigned char[]>(desc->size);
+  if (desc->cmask==nullptr)
   {
     DDD_PrintError('E', 2413,
                    RegisterError(desc,0, STR_NOMEM));
@@ -444,7 +444,7 @@ static void AttachMask (TYPE_DESC *desc)
   for(i=0; i<desc->nElements; i++)
   {
     e = &desc->element[i];
-    mp = desc->cmask + e->offset;
+    mp = desc->cmask.get() + e->offset;
 
     switch (e->type)
     {
@@ -859,7 +859,7 @@ DDD_TYPE DDD_TypeDeclare(const char *name)
   desc->mode = DDD_TYPE_DECLARED;
   desc->name = name;
 
-  desc->prioMatrix  = NULL;
+  desc->prioMatrix  = nullptr;
   desc->prioDefault = PRIOMERGE_DEFAULT;
 
   /* increase #DDD_TYPEs, but return previously defined one */
@@ -905,7 +905,7 @@ void DDD_TypeDisplay (DDD_TYPE id)
     }
 
     /* print header */
-    sprintf(cBuffer, "/ Structure of %s--object '%s', id %d, %d byte\n",
+    sprintf(cBuffer, "/ Structure of %s--object '%s', id %d, %zd byte\n",
             desc->hasHeader ? "DDD" : "data",
             desc->name, id, desc->size);
     DDD_PrintLine(cBuffer);
@@ -935,7 +935,7 @@ void DDD_TypeDisplay (DDD_TYPE id)
           e->offset < desc->offsetHeader ||
           e->offset >= desc->offsetHeader+theTypeDefs[EL_DDDHDR].size)
       {
-        sprintf(cBuffer, "|%5d %5d    ", e->offset, e->size);
+        sprintf(cBuffer, "|%5d %5zd    ", e->offset, e->size);
 
 
         /* print one line according to type */
@@ -988,7 +988,7 @@ void DDD_TypeDisplay (DDD_TYPE id)
         /* handle included DDD_HDR */
         if (e->offset == desc->offsetHeader)
         {
-          sprintf(cBuffer, "|%5d %5d    ddd-header\n",
+          sprintf(cBuffer, "|%5d %5zd    ddd-header\n",
                   e->offset, theTypeDefs[EL_DDDHDR].size);
           DDD_PrintLine(cBuffer);
         }
@@ -1003,22 +1003,6 @@ void DDD_TypeDisplay (DDD_TYPE id)
 
 
 
-/****************************************************************************/
-/*                                                                          */
-/* Function:  DDD_HandlerRegister                                           */
-/*                                                                          */
-/* Purpose:   register handlers for given DDD_TYPE                          */
-/*                                                                          */
-/* Input:     typeId, handler_name, func_ptr, ... (last two repeated)      */
-/*            with: typeId: DDD_TYPE for which handlers will be registered */
-/*                  handler_name:  one of HANDLER_xxx                       */
-/*                  func_ptr:      pointer to function implementing handler */
-/*            the argument list must be finished with HANDLER_END.          */
-/*                                                                          */
-/* Output:    -                                                             */
-/*                                                                          */
-/****************************************************************************/
-
 static void InitHandlers (TYPE_DESC *desc)
 {
   /* set all handler functions to default (=none) */
@@ -1078,114 +1062,6 @@ static void InitHandlers (TYPE_DESC *desc)
 #include "handler.ct"
 
 
-/**
-        Registration of handler functions.
-
-        {\em This function is supported for downward compatibility only.
-        (Use new DDD\_SetHandlerXXX-functions instead. Advantage: static type
-        checking for handler functions).}
-
-        This function registers a list of handlers for a certain DDD
-        object type. The list may contain each handler type {\tt HANDLER\_}
-        as listed in this manual. Usually, \funk{HandlerRegister} will be called
-        once after initialization of the corresponding \cod{DDD\_TYPE}.
-
-        It is possible to define certain sets of handler functions and switch them
-        at runtime; \eg, a set for load migration and another set for distributed
-        grid refinement can be defined. Before executing the actual task, the
-        handler set must be registered.
-
-        variable argumentlist...
-
-   @param typeId  DDD type of object for which the handlers will be registered.
- */
-void DDD_HandlerRegister (DDD_TYPE typeId, ...)
-{
-TYPE_DESC *desc = &(theTypeDefs[typeId]);
-int idx;
-va_list ap;
-
-OLDSTYLE("DDD_HandlerRegister() supported for downward compatibility only.");
-OLDSTYLE("  (Use new DDD_SetHandlerXXX-functions instead.");
-OLDSTYLE("   Advantage: static type checking for handler functions)");
-
-if (desc->mode != DDD_TYPE_DEFINED)
-{
-  DDD_PrintError('E', 2429,
-                 "undefined DDD_TYPE in DDD_HandlerRegister()");
-  HARD_EXIT;               /*return;*/
-}
-
-/* read argument list, fill object structure definition */
-va_start(ap, typeId);
-
-while ((idx = va_arg(ap, int)) != HANDLER_END)
-{
-  switch(idx)
-  {
-  case HANDLER_LDATACONSTRUCTOR :
-    desc->handlerLDATACONSTRUCTOR =
-      va_arg(ap, HandlerLDATACONSTRUCTOR);
-    break;
-  case HANDLER_DESTRUCTOR :
-    desc->handlerDESTRUCTOR =
-      va_arg(ap, HandlerDESTRUCTOR);
-    break;
-  case HANDLER_DELETE :
-    desc->handlerDELETE =
-      va_arg(ap, HandlerDELETE);
-    break;
-  case HANDLER_UPDATE :
-    desc->handlerUPDATE =
-      va_arg(ap, HandlerUPDATE);
-    break;
-  case HANDLER_OBJMKCONS :
-    desc->handlerOBJMKCONS =
-      va_arg(ap, HandlerOBJMKCONS);
-    break;
-  case HANDLER_SETPRIORITY :
-    desc->handlerSETPRIORITY =
-      va_arg(ap, HandlerSETPRIORITY);
-    break;
-  case HANDLER_XFERCOPY :
-    desc->handlerXFERCOPY =
-      va_arg(ap, HandlerXFERCOPY);
-    break;
-  case HANDLER_XFERDELETE :
-    desc->handlerXFERDELETE =
-      va_arg(ap, HandlerXFERDELETE);
-    break;
-  case HANDLER_XFERGATHER :
-    desc->handlerXFERGATHER =
-      va_arg(ap, HandlerXFERGATHER);
-    break;
-  case HANDLER_XFERSCATTER :
-    desc->handlerXFERSCATTER =
-      va_arg(ap, HandlerXFERSCATTER);
-    break;
-  case HANDLER_XFERGATHERX :
-    desc->handlerXFERGATHERX =
-      va_arg(ap, HandlerXFERGATHERX);
-    break;
-  case HANDLER_XFERSCATTERX :
-    desc->handlerXFERSCATTERX =
-      va_arg(ap, HandlerXFERSCATTERX);
-    break;
-  case HANDLER_XFERCOPYMANIP :
-    desc->handlerXFERCOPYMANIP =
-      va_arg(ap, HandlerXFERCOPYMANIP);
-    break;
-  default :
-    DDD_PrintError('E', 2430,
-                   "undefined HandlerId in DDD_HandlerRegister()");
-    HARD_EXIT;
-  }
-}
-
-va_end(ap);
-}
-
-
 /****************************************************************************/
 /*                                                                          */
 /* Function:  DDD_InfoTypes                                                 */
@@ -1297,10 +1173,7 @@ void ddd_TypeMgrExit (void)
   /* free memory */
   for(i=0; i<nDescr; i++)
   {
-    if (theTypeDefs[i].cmask!=NULL) {
-      FreeFix(theTypeDefs[i].cmask);
-      theTypeDefs[i].cmask = NULL;
-    }
+    theTypeDefs[i].cmask = nullptr;
   }
 }
 
