@@ -41,7 +41,7 @@
 #include "architecture.h"
 #include "debug.h"
 #include "ugtypes.h"
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 #include "domain.h"
 #include "evm.h"
 #include "parallel.h"
@@ -237,7 +237,6 @@ static void VectorXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   MATRIX  *mat;
   VECTOR  *pv             = (VECTOR *)obj;
   INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(pv)));
-  GRID            *theGrid        = GRID_ON_LEVEL(dddctrl.currMG,level);
   /* TODO: define this static global                    */
   /* TODO: take size as maximum of possible connections */
   size_t sizeArray[256];
@@ -269,6 +268,7 @@ static void VectorXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   /*
           else
           {
+                  GRID *theGrid = GRID_ON_LEVEL(dddctrl.currMG,level);
                   MATRIX *theMatrix,*next;
 
                   for (theMatrix=VSTART(pv); theMatrix!=NULL; theMatrix = next) {
@@ -625,8 +625,6 @@ static void VectorObjMkCons (DDD_OBJ obj, int newness)
 
     if (MDEST(theAdjoint) == NULL)
     {
-      CONNECTION *con = MMYCON(theMatrix);
-
       PRINTDEBUG(dddif,4,(PFMT " VectorObjMkCons(): v=" VINDEX_FMTX
                           " mat=%x vectoID=%d, KILLING incomplete connection\n",
                           me,VINDEX_PRTX(vec),theMatrix,ID(MDEST(theMatrix))))
@@ -703,9 +701,6 @@ static void VectorPriorityUpdate (DDD_OBJ obj, DDD_PRIO isnew)
         if (DisposeConnection(theGrid,MMYCON(theMatrix)))
           ASSERT(0);
       }
-                        #ifdef __INTERPOLATION_MATRIX__
-      if (DisposeIMatrixList(theGrid,pv)) assert(0);
-                        #endif
     }
 #endif
 
@@ -815,21 +810,32 @@ static void BVertexGather (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data)
  * The first sizeof(int) bytes of the message_buffer is the length of
  * the message (without the size of the int).
  */
-static void DuneNodeGather (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data)
+template<typename Entity>
+static void DuneEntityGather (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data)
 {
-  int dataSize = ((int*)(((NODE*)obj)->message_buffer))[0];
+  char* data = static_cast<char*>(Data);
+  const Entity* entity = reinterpret_cast<Entity*>(obj);
+  const auto size = entity->message_buffer_size();
 
-  for (int i=0; i<dataSize + sizeof(int); i++)
-    ((char*)Data)[i] = (((NODE*)obj)->message_buffer)[i];
+  std::memcpy(data, &size, sizeof size);
+  data += sizeof size;
+
+  std::memcpy(data, entity->message_buffer(), size);
 }
 
-static void DuneNodeScatter (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data, int newness)
+template<typename Entity>
+static void DuneEntityScatter (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data, int newness)
 {
-  int dataSize = ((int*)Data)[0];
-  ((NODE*)obj)->message_buffer = (char*)malloc(sizeof(int) + dataSize);
+  const char* data = static_cast<const char*>(Data);
+  Entity* entity = reinterpret_cast<Entity*>(obj);
 
-  for (int i=0; i<dataSize + sizeof(int); i++)
-    (((NODE*)obj)->message_buffer)[i] = ((char*)Data)[i];
+  std::size_t size;
+  std::memcpy(&size, data, sizeof size);
+  data += sizeof size;
+
+  char* buffer = static_cast<char*>(std::malloc(size));
+  std::memcpy(buffer, data, size);
+  entity->message_buffer(buffer, size);
 }
 
 static void BVertexScatter (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *Data, int newness)
@@ -885,6 +891,8 @@ static void NodeDestructor(DDD_OBJ obj)
 {
   NODE *node      = (NODE *) obj;
 
+  node->message_buffer_free();
+
   PRINTDEBUG(dddif,2,(PFMT " NodeDestructor(): n=" ID_FMTX " NDOBJ=%d\n",
                       me,ID_PRTX(node),OBJT(node)))
 }
@@ -893,6 +901,8 @@ static void NodeObjInit(DDD_OBJ obj)
 {
   NODE *node      = (NODE *) obj;
 
+  node->message_buffer(nullptr, 0);
+
   PRINTDEBUG(dddif,2,(PFMT " NodeObjInit(): n=" ID_FMTX " NDOBJ=%d\n",
                       me,ID_PRTX(node),OBJT(node)))
 }
@@ -1031,8 +1041,6 @@ static void NodeUpdate (DDD_OBJ obj)
 
 static void NodeXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
 {
-  INT nlink           = 0;
-  INT Size,i          = 0;
   NODE    *theNode        = (NODE *)obj;
   VECTOR  *vec            = NULL;
 
@@ -1069,9 +1077,9 @@ static void NodeXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   }
         #endif
 
-  if (DDD_XferWithAddData() && theNode->message_buffer) {
+  if (DDD_XferWithAddData()) {
     /* Extra data for Dune */
-    DDD_XferAddData(sizeof(int) + *((INT*)theNode->message_buffer), DDD_USER_DATA);
+    DDD_XferAddData(sizeof(theNode->message_buffer_size()) + theNode->message_buffer_size(), DDD_USER_DATA);
   }
 
   DDD_XferCopyObj(PARHDRV(MYVERTEX(theNode)), proc, prio);
@@ -1081,7 +1089,7 @@ static void NodeXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   {
     vec = NVECTOR(theNode);
     if (vec != NULL) {
-      Size = sizeof(VECTOR)-sizeof(DOUBLE)
+      INT Size = sizeof(VECTOR)-sizeof(DOUBLE)
              +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(vec));
 
       PRINTDEBUG(dddif,2,(PFMT " NodeXferCopy(): n=" ID_FMTX
@@ -1187,7 +1195,8 @@ static void ElementLDataConstructor (DDD_OBJ obj)
   INT level           = LEVEL(pe);
   GRID    *theGrid        = GetGridOnDemand(dddctrl.currMG,level);
   INT prio            = EPRIO(pe);
-  void    *q;
+
+  pe->message_buffer(nullptr, 0);
 
   PRINTDEBUG(dddif,2,(PFMT " ElementLDataConsX(): pe=" EID_FMTX
                       " EOBJ=%d l=%d\n",me,EID_PRTX(pe),OBJT(pe),level))
@@ -1205,12 +1214,6 @@ static void ElementLDataConstructor (DDD_OBJ obj)
   /* TODO: delete
      ID(pe) = (theGrid->mg->elemIdCounter)++;
    */
-
-  if (EDATA_DEF_IN_GRID(theGrid)) {
-    q = (void *) GetMemoryForObject(theGrid->mg,EDATA_DEF_IN_GRID(theGrid),NOOBJ);
-    ASSERT(q != NULL);
-    SET_EDATA(pe,q);
-  }
 }
 
 /****************************************************************************/
@@ -1228,7 +1231,6 @@ static void ElementLDataConstructor (DDD_OBJ obj)
 
 static void ElementUpdate (DDD_OBJ obj)
 {
-  INT i;
   ELEMENT *pe                     = (ELEMENT *)obj;
 
   PRINTDEBUG(dddif,1,(PFMT " ElementUpdate(): pe=" EID_FMTX
@@ -1317,9 +1319,7 @@ static void ElementXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   }
 
   if (DDD_XferWithAddData()) {
-
-    if (EDATA_DEF_IN_MG(dddctrl.currMG))
-      DDD_XferAddData(EDATA_DEF_IN_MG(dddctrl.currMG), DDD_USER_DATA);
+    DDD_XferAddData(sizeof(pe->message_buffer_size()) + pe->message_buffer_size(), DDD_USER_DATA);
 
     /* add edges of element */
     /* must be done before any XferCopyObj-call! herein    */
@@ -1344,11 +1344,7 @@ static void ElementXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
   /* send edge and edge vectors */
   for (i=0; i<EDGES_OF_ELEM(pe); i++)
   {
-    int Size;
-    EDGE    *edge;
-    VECTOR  *vec;
-
-    edge = GetEdge(CORNER(pe,CORNER_OF_EDGE(pe,i,0)),
+    EDGE* edge = GetEdge(CORNER(pe,CORNER_OF_EDGE(pe,i,0)),
                    CORNER(pe,CORNER_OF_EDGE(pe,i,1)));
     ASSERT(edge != NULL);
     ASSERT(OBJT(edge) == EDOBJ);
@@ -1364,7 +1360,7 @@ static void ElementXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
       VECTOR *vec = EDVECTOR(edge);
 
       if (vec != NULL) {
-        Size = sizeof(VECTOR)-sizeof(DOUBLE)
+        int Size = sizeof(VECTOR)-sizeof(DOUBLE)
                +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(vec));
         PRINTDEBUG(dddif,3,(PFMT " ElementXferCopy():  e=" EID_FMTX
                             " EDGEVEC=" VINDEX_FMTX " size=%d\n",
@@ -1416,23 +1412,6 @@ static void ElementXferCopy (DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
 
 /****************************************************************************/
 
-static void ElemGatherEdata (ELEMENT *pe, int cnt, char *data)
-{
-  ASSERT(cnt == EDATA_DEF_IN_MG(dddctrl.currMG));
-
-  memcpy(data,(char*)EDATA(pe),cnt);
-  return;
-}
-
-static void ElemScatterEdata (ELEMENT *pe, int cnt, char *data)
-{
-  ASSERT(cnt == EDATA_DEF_IN_MG(dddctrl.currMG));
-
-  memcpy((char*)EDATA(pe),data,cnt);
-  return;
-}
-
-
 #ifdef __TWODIM__
 static void ElemGatherEdge (ELEMENT *pe, int cnt, char *data)
 {
@@ -1611,7 +1590,7 @@ static void ElemGatherI (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *data)
 {
   if (type_id == DDD_USER_DATA)
   {
-    ElemGatherEdata((ELEMENT *)obj, cnt, (char *)data);
+    DuneEntityGather<union element>(obj, cnt, type_id, data);
     return;
   }
 
@@ -1627,7 +1606,7 @@ static void ElemScatterI (DDD_OBJ obj, int cnt, DDD_TYPE type_id,
 {
   if (type_id == DDD_USER_DATA)
   {
-    ElemScatterEdata((ELEMENT *)obj, cnt, (char *)data);
+    DuneEntityScatter<union element>(obj, cnt, type_id, data, newness);
     return;
   }
 
@@ -1653,7 +1632,7 @@ static void ElemGatherB (DDD_OBJ obj, int cnt, DDD_TYPE type_id, void *data)
   }
   if (type_id == DDD_USER_DATA)
   {
-    ElemGatherEdata((ELEMENT *)obj, cnt,(char *)data);
+    DuneEntityGather<union element>(obj, cnt, type_id, data);
     return;
   }
 
@@ -1686,7 +1665,7 @@ static void ElemScatterB (DDD_OBJ obj, int cnt, DDD_TYPE type_id,
   }
   if (type_id == DDD_USER_DATA)
   {
-    ElemScatterEdata((ELEMENT *)obj, cnt,(char *)data);
+    DuneEntityScatter<union element>(obj, cnt, type_id, data, newness);
     return;
   }
 
@@ -1752,7 +1731,7 @@ static void ElementObjMkCons (DDD_OBJ obj, int newness)
           then you have eventually to unlink and link
           an element again to avoid
           decoupling of element and its father.
-          Sample cenario:
+          Sample scenario:
                   father=a  son=x are on proc p.
                   father is deleted and removes his reference in son,
                   but father and son are sent again to p. Son x gets
@@ -2031,8 +2010,6 @@ static void ElementPriorityUpdate (DDD_OBJ obj, DDD_PRIO new_)
 static void EdgeUpdate (DDD_OBJ obj)
 {
   EDGE    *pe                     = (EDGE *)obj;
-  LINK    *link0,
-  *link1;
   INT level           = LEVEL(NBNODE(LINK0(pe)));
   GRID    *theGrid        = GetGridOnDemand(dddctrl.currMG,level);
 
@@ -2041,20 +2018,17 @@ static void EdgeUpdate (DDD_OBJ obj)
                       me,pe,DDD_InfoGlobalId(PARHDR(pe)),OBJT(pe),NO_OF_ELEM(pe)))
 
   {
-    LINK *link0,*link1;
-    NODE *node0,*node1;
-
     /* insert in link lists of nodes */
-    link0 = LINK0(pe);
-    link1 = LINK1(pe);
+    LINK* link0 = LINK0(pe);
+    LINK* link1 = LINK1(pe);
 
     PRINTDEBUG(dddif,2,(PFMT " EdgeUpdate(): edge=%x/%08x node0="
                         ID_FMTX " node1=" ID_FMTX "\n",
                         me,pe,DDD_InfoGlobalId(PARHDR(pe)),
                         ID_PRTX(NBNODE(link1)),ID_PRTX(NBNODE(link0))))
 
-    node0 = NBNODE(link1);
-    node1 = NBNODE(link0);
+    NODE* node0 = NBNODE(link1);
+    NODE* node1 = NBNODE(link0);
 
     NEXT(link0) = START(node0);
     START(node0) = link0;
@@ -2083,9 +2057,10 @@ static void EdgePriorityUpdate (DDD_OBJ obj, DDD_PRIO new_)
 {
   EDGE    *theEdge        = (EDGE *)obj;
   INT level           = LEVEL(theEdge);
-  GRID    *theGrid        = GetGridOnDemand(dddctrl.currMG,level);
   INT old                     = PRIO(theEdge);
 
+  GetGridOnDemand(dddctrl.currMG,level);
+
   PRINTDEBUG(dddif,2,(PFMT " EdgePriorityUpdate(): n=" ID_FMTX " old=%d new_=%d "
                       "level=%d\n",me,ID_PRTX(theEdge),old,new_,level))
 }
@@ -2233,8 +2208,8 @@ void NS_DIM_PREFIX ddd_HandlerInit (INT handlerSet)
   DDD_SetHandlerXFERSCATTER      (TypeBVertex, BVertexScatter);
   DDD_SetHandlerSETPRIORITY      (TypeBVertex, VertexPriorityUpdate);
 
-  DDD_SetHandlerXFERGATHER       (TypeNode, DuneNodeGather);
-  DDD_SetHandlerXFERSCATTER      (TypeNode, DuneNodeScatter);
+  DDD_SetHandlerXFERGATHER       (TypeNode, DuneEntityGather<NODE>);
+  DDD_SetHandlerXFERSCATTER      (TypeNode, DuneEntityScatter<NODE>);
 
   DDD_SetHandlerLDATACONSTRUCTOR (TypeNode, NodeObjInit);
   DDD_SetHandlerDESTRUCTOR       (TypeNode, NodeDestructor);
