@@ -36,7 +36,7 @@
 #include "general.h"
 #include "ugm.h"      /* for GetFreeOBJT() */
 #include "memmgr.h"
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 #include "namespace.h"
 
 /* UG namespaces: */
@@ -437,15 +437,6 @@ static void ddd_DefineTypes (void)
                  EL_GDATA,  ELDEF(v.skip),
                  EL_LDATA,  ELDEF(v.start),
 
-                 /* TODO is this LDATA or GDATA? */
-                #ifdef __BLOCK_VECTOR_DESC__
-                 EL_LDATA,  ELDEF(v.block_descr),
-                #endif
-
-                #ifdef __INTERPOLATION_MATRIX__
-                 EL_LDATA,  ELDEF(v.istart),
-                #endif
-
                  /* TODO: value wird noch ausgelassen. feld variabler laenge? */
                  /* bei entscheidung 'value': kein weiteres feld
                          bei ent. 'userdata *': EL_GDATA-feld        */
