@@ -43,7 +43,7 @@
 #include "namespace.h"
 
 /* dev module */
-#include "ugdevices.h"
+#include <dev/ugdevices.h>
 
 /* gm module */
 #include "algebra.h"
@@ -421,7 +421,6 @@ INT ConnectGridOverlap (GRID *theGrid)
         if (!EHGHOST(theSon)) continue;
         for (j=0; j<SIDES_OF_ELEM(theSon); j++)
         {
-          INT k;
           ELEMENT *NbSon = NBELEM(theSon,j);
 
           if (NbSon == NULL) continue;
@@ -434,6 +433,7 @@ INT ConnectGridOverlap (GRID *theGrid)
           /* TODO: delete this is done in ElementObjMkCons()
                                                   else
                                                   {
+                                                          INT k;
                                                           for (k=0; k<SIDES_OF_ELEM(NbSon); k++)
                                                           {
                                                                   if (NBELEM(NbSon,k)==theSon) break;
@@ -649,7 +649,7 @@ INT ConnectVerticalOverlap (MULTIGRID *theMG)
 
 static INT ConnectOverlapVerticalGrid (GRID *theGrid)
 {
-  INT i,j,k,found,edgenode0,edgenode1,edgenum;
+  INT i,j,k,found,edgenode0,edgenode1;
   ELEMENT *theElement,*theSon,*SonList[MAX_SONS];
   NODE    *theNode,*SonNode,*FatherNode,*EdgeNode0,*EdgeNode1;
   EDGE    *theEdge,*FatherEdge;
@@ -742,7 +742,6 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
               SETNFATHER(SonNode,(GEOM_OBJECT *)theEdge);
               MIDNODE(theEdge) = SonNode;
               found ++;
-              edgenum = k;
 
               /* reconstruct vertex information */
               theVertex = MYVERTEX(SonNode);
